==> tv-cli-0.5.3.crate: tv-cli-0.5.3/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

## [v0.5.3](https://github.com/uzimaru0000/tv/releases/tag/v0.5.3) - 2021-09-12

### Features

- :sparkles: Add completions files
 ([e9932a8](https://github.com/uzimaru0000/tv/commit/e9932a8460fc5b4ed3815df31e74012b04213e8a))

## [v0.5.2](https://github.com/uzimaru0000/tv/releases/tag/v0.5.2) - 2021-09-12

### Documentation

- :books: update README.md
 ([c28e7f3](https://github.com/uzimaru0000/tv/commit/c28e7f30ce5cb9391580c32e9ff287fe9b61f704))
- :books: Update README
 ([8959ab1](https://github.com/uzimaru0000/tv/commit/8959ab13b0c928bd6df5bd259cef58b132f9a892))

## [v0.5.1](https://github.com/uzimaru0000/tv/releases/tag/v0.5.1) - 2021-09-07

### Documentation

- :books: change logo in README
 ([6a19374](https://github.com/uzimaru0000/tv/commit/6a19374f179675aace3961dbec6f51855498e2bc))

### Miscellaneous Tasks

- :adhesive_bandage: fix logo color
 ([730f883](https://github.com/uzimaru0000/tv/commit/730f883956d7d95ea710c8679e8680d8dc07b404))
- :adhesive_bandage: change something
 ([48ba03f](https://github.com/uzimaru0000/tv/commit/48ba03f5e0c98466a454fc653f2dcd1e172ddb7d))

### Refactor

- :recycle: update package name
 ([8486d8c](https://github.com/uzimaru0000/tv/commit/8486d8cac7f84605457424b740ad00d333509856))

## [v0.5.0](https://github.com/uzimaru0000/tv/releases/tag/v0.5.0) - 2021-09-05

### Bug Fixes

- :bug: fixed field order
 ([8e9224d](https://github.com/uzimaru0000/tv/commit/8e9224d25273209bfd03a6a432ea3e18587de8ec))

### Documentation

- :books: change test.json → example.json
 ([8cb3ce5](https://github.com/uzimaru0000/tv/commit/8cb3ce5bd5d1f02ce2e6959ad488f6e377658dec))

### Features

- :sparkles: add no-headers mode
 ([8a92630](https://github.com/uzimaru0000/tv/commit/8a92630745e88851ec34c017aca90f08469a7f25))
- :sparkles: add recursive view
 ([36bbd46](https://github.com/uzimaru0000/tv/commit/36bbd462bf3f3a170738a9fd73156fe21805bd78))

## [v0.4.0](https://github.com/uzimaru0000/tv/releases/tag/v0.4.0) - 2021-09-05

### Documentation

- :books: add commit_template
 ([663e4db](https://github.com/uzimaru0000/tv/commit/663e4db4d98d1068c5c9249a8e36ea06ff529df0))
- :books: update README
 ([17ec417](https://github.com/uzimaru0000/tv/commit/17ec41701c3d9f2d3b95fc47fbd0b74122fd6345))

### Features

- :sparkles: Frame style & Multiline
 ([1d39298](https://github.com/uzimaru0000/tv/commit/1d39298a4fee627f34cb86e36da6d52cf1dc4c3e))

### Testing

- :rotating_light: fix test case
 ([2c6f20c](https://github.com/uzimaru0000/tv/commit/2c6f20c3682ad49243d5d9ad88d70075da66483d))

## [v0.3.1](https://github.com/uzimaru0000/tv/releases/tag/v0.3.1) - 2021-08-31

### Documentation

- :books: update Cargo.toml
 ([468979c](https://github.com/uzimaru0000/tv/commit/468979c8321e96662ee28be76cff0c01db6bfa32))

### Refactor

- :recycle: Refactoring code
 ([1ac2533](https://github.com/uzimaru0000/tv/commit/1ac25336c18bf4e16da46f954cc877cd3f792135))

## [v0.3.0](https://github.com/uzimaru0000/tv/releases/tag/v0.3.0) - 2021-08-31

### Documentation

- :books: update README.md
 ([4eab200](https://github.com/uzimaru0000/tv/commit/4eab2007b684592068ddaeb3346850b609aed0fa))

### Features

- :sparkles: can view array
 ([4a553e6](https://github.com/uzimaru0000/tv/commit/4a553e6ebe8b6bc1778aa43b3c1c74554db5cb57))

## [v0.2.1](https://github.com/uzimaru0000/tv/releases/tag/v0.2.1) - 2021-08-29

### Bug Fixes

- :bug: fix title align
 ([a1e9256](https://github.com/uzimaru0000/tv/commit/a1e925611b95a7e25c007e2d4e0c66a6a599a263))

### Documentation

- :books: update CHANGELOG.md
 ([d3f285e](https://github.com/uzimaru0000/tv/commit/d3f285ef17dd37145b7fb24cf82bdd8398f114ab))
- :books: add LICENSE
 ([0c127da](https://github.com/uzimaru0000/tv/commit/0c127da130557b28273212cfd9b57aa2be00c032))

## [v0.2.0](https://github.com/uzimaru0000/tv/releases/tag/v0.2.0) - 2021-08-28

### Documentation

- :books: update CHANGELOG.md
 ([b7dc35e](https://github.com/uzimaru0000/tv/commit/b7dc35e5057177ad23194af20e6b83ec98c62a52))

### Features

- :sparkles: sort option
 ([b4db8c7](https://github.com/uzimaru0000/tv/commit/b4db8c775a8b55877f08815af09dabce77cd6997))
- :sparkles: plane option
 ([5374510](https://github.com/uzimaru0000/tv/commit/5374510922fa7e7b84943cbc1f84a1ee653ade5d))
- :sparkles: align option
 ([35407c7](https://github.com/uzimaru0000/tv/commit/35407c76eeb788dcd78cfe68f32e18096ced5037))

## [v0.1.2](https://github.com/uzimaru0000/tv/releases/tag/v0.1.2) - 2021-08-27

### Documentation

- :books: change install
 ([4c332df](https://github.com/uzimaru0000/tv/commit/4c332df99e163d73709334f3704bd83efa7b53e6))

### Features

- :sparkles: impl help message
 ([a02ae0d](https://github.com/uzimaru0000/tv/commit/a02ae0dd5d483f94619d5aae42763eede012c25b))

## [v0.1.1](https://github.com/uzimaru0000/tv/releases/tag/v0.1.1) - 2021-08-26

## [v0.1.0](https://github.com/uzimaru0000/tv/releases/tag/v0.1.0) - 2021-08-26

### Bug Fixes

- :bug: fix ci error
 ([29abf6a](https://github.com/uzimaru0000/tv/commit/29abf6ad89ec04b6867e0f48c69e6131474a197d))

### Documentation

- :books: add README
 ([a127b08](https://github.com/uzimaru0000/tv/commit/a127b0881d26ec626fffee86fc3d29a59bfc247d))

<!-- generated by git-cliff -->

==> tv-cli-0.7.0.crate: tv-cli-0.7.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

## [v0.7.0](https://github.com/uzimaru0000/tv/releases/tag/v0.7.0) - 2021-09-24

### Bug Fixes

- :bug: fix header border in markdown style
 ([c43c22e](https://github.com/uzimaru0000/tv/commit/c43c22ef31ea7e4b043a9dd7f5c7da95c3e2f636))
- :bug: Set minimum width
 ([83c7251](https://github.com/uzimaru0000/tv/commit/83c7251bff4ffc8b76856db83e7832431cb2fcca))

### Features

- :sparkles: Add an option to pick any field
 ([fbca75a](https://github.com/uzimaru0000/tv/commit/fbca75aacb637f2e7bbc32afa1d1200341de285a))

## [v0.6.0](https://github.com/uzimaru0000/tv/releases/tag/v0.6.0) - 2021-09-20

### Bug Fixes

- :bug: fixed sorted when -r option
 ([06eb9d3](https://github.com/uzimaru0000/tv/commit/06eb9d3d3fd7cc608c6fc65be042f7f038d70a9f))

### Features

- :sparkles: Can use nested sort key
 ([2bba300](https://github.com/uzimaru0000/tv/commit/2bba300828ace070aab4cab590aba01cd70d920e))

### Miscellaneous Tasks

- :adhesive_bandage: fix actions
 ([784f569](https://github.com/uzimaru0000/tv/commit/784f569366a9f9d654f000cd55a3e9129f8127f1))

## [v0.5.3](https://github.com/uzimaru0000/tv/releases/tag/v0.5.3) - 2021-09-14

### Features

- :sparkles: Add completions files
 ([e9932a8](https://github.com/uzimaru0000/tv/commit/e9932a8460fc5b4ed3815df31e74012b04213e8a))

## [v0.5.2](https://github.com/uzimaru0000/tv/releases/tag/v0.5.2) - 2021-09-12

### Documentation

- :books: update README.md
 ([c28e7f3](https://github.com/uzimaru0000/tv/commit/c28e7f30ce5cb9391580c32e9ff287fe9b61f704))
- :books: Update README
 ([8959ab1](https://github.com/uzimaru0000/tv/commit/8959ab13b0c928bd6df5bd259cef58b132f9a892))

## [v0.5.1](https://github.com/uzimaru0000/tv/releases/tag/v0.5.1) - 2021-09-07

### Documentation

- :books: change logo in README
 ([6a19374](https://github.com/uzimaru0000/tv/commit/6a19374f179675aace3961dbec6f51855498e2bc))

### Miscellaneous Tasks

- :adhesive_bandage: fix logo color
 ([730f883](https://github.com/uzimaru0000/tv/commit/730f883956d7d95ea710c8679e8680d8dc07b404))
- :adhesive_bandage: change something
 ([48ba03f](https://github.com/uzimaru0000/tv/commit/48ba03f5e0c98466a454fc653f2dcd1e172ddb7d))

### Refactor

- :recycle: update package name
 ([8486d8c](https://github.com/uzimaru0000/tv/commit/8486d8cac7f84605457424b740ad00d333509856))

## [v0.5.0](https://github.com/uzimaru0000/tv/releases/tag/v0.5.0) - 2021-09-05

### Bug Fixes

- :bug: fixed field order
 ([8e9224d](https://github.com/uzimaru0000/tv/commit/8e9224d25273209bfd03a6a432ea3e18587de8ec))

### Documentation

- :books: change test.json → example.json
 ([8cb3ce5](https://github.com/uzimaru0000/tv/commit/8cb3ce5bd5d1f02ce2e6959ad488f6e377658dec))

### Features

- :sparkles: add no-headers mode
 ([8a92630](https://github.com/uzimaru0000/tv/commit/8a92630745e88851ec34c017aca90f08469a7f25))
- :sparkles: add recursive view
 ([36bbd46](https://github.com/uzimaru0000/tv/commit/36bbd462bf3f3a170738a9fd73156fe21805bd78))

## [v0.4.0](https://github.com/uzimaru0000/tv/releases/tag/v0.4.0) - 2021-09-05

### Documentation

- :books: add commit_template
 ([663e4db](https://github.com/uzimaru0000/tv/commit/663e4db4d98d1068c5c9249a8e36ea06ff529df0))
- :books: update README
 ([17ec417](https://github.com/uzimaru0000/tv/commit/17ec41701c3d9f2d3b95fc47fbd0b74122fd6345))

### Features

- :sparkles: Frame style & Multiline
 ([1d39298](https://github.com/uzimaru0000/tv/commit/1d39298a4fee627f34cb86e36da6d52cf1dc4c3e))

### Testing

- :rotating_light: fix test case
 ([2c6f20c](https://github.com/uzimaru0000/tv/commit/2c6f20c3682ad49243d5d9ad88d70075da66483d))

## [v0.3.1](https://github.com/uzimaru0000/tv/releases/tag/v0.3.1) - 2021-08-31

### Documentation

- :books: update Cargo.toml
 ([468979c](https://github.com/uzimaru0000/tv/commit/468979c8321e96662ee28be76cff0c01db6bfa32))

### Refactor

- :recycle: Refactoring code
 ([1ac2533](https://github.com/uzimaru0000/tv/commit/1ac25336c18bf4e16da46f954cc877cd3f792135))

## [v0.3.0](https://github.com/uzimaru0000/tv/releases/tag/v0.3.0) - 2021-08-31

### Documentation

- :books: update README.md
 ([4eab200](https://github.com/uzimaru0000/tv/commit/4eab2007b684592068ddaeb3346850b609aed0fa))

### Features

- :sparkles: can view array
 ([4a553e6](https://github.com/uzimaru0000/tv/commit/4a553e6ebe8b6bc1778aa43b3c1c74554db5cb57))

## [v0.2.1](https://github.com/uzimaru0000/tv/releases/tag/v0.2.1) - 2021-08-29

### Bug Fixes

- :bug: fix title align
 ([a1e9256](https://github.com/uzimaru0000/tv/commit/a1e925611b95a7e25c007e2d4e0c66a6a599a263))

### Documentation

- :books: update CHANGELOG.md
 ([d3f285e](https://github.com/uzimaru0000/tv/commit/d3f285ef17dd37145b7fb24cf82bdd8398f114ab))
- :books: add LICENSE
 ([0c127da](https://github.com/uzimaru0000/tv/commit/0c127da130557b28273212cfd9b57aa2be00c032))

## [v0.2.0](https://github.com/uzimaru0000/tv/releases/tag/v0.2.0) - 2021-08-28

### Documentation

- :books: update CHANGELOG.md
 ([b7dc35e](https://github.com/uzimaru0000/tv/commit/b7dc35e5057177ad23194af20e6b83ec98c62a52))

### Features

- :sparkles: sort option
 ([b4db8c7](https://github.com/uzimaru0000/tv/commit/b4db8c775a8b55877f08815af09dabce77cd6997))
- :sparkles: plane option
 ([5374510](https://github.com/uzimaru0000/tv/commit/5374510922fa7e7b84943cbc1f84a1ee653ade5d))
- :sparkles: align option
 ([35407c7](https://github.com/uzimaru0000/tv/commit/35407c76eeb788dcd78cfe68f32e18096ced5037))

## [v0.1.2](https://github.com/uzimaru0000/tv/releases/tag/v0.1.2) - 2021-08-27

### Documentation

- :books: change install
 ([4c332df](https://github.com/uzimaru0000/tv/commit/4c332df99e163d73709334f3704bd83efa7b53e6))

### Features

- :sparkles: impl help message
 ([a02ae0d](https://github.com/uzimaru0000/tv/commit/a02ae0dd5d483f94619d5aae42763eede012c25b))

## [v0.1.1](https://github.com/uzimaru0000/tv/releases/tag/v0.1.1) - 2021-08-26

## [v0.1.0](https://github.com/uzimaru0000/tv/releases/tag/v0.1.0) - 2021-08-26

### Bug Fixes

- :bug: fix ci error
 ([29abf6a](https://github.com/uzimaru0000/tv/commit/29abf6ad89ec04b6867e0f48c69e6131474a197d))

### Documentation

- :books: add README
 ([a127b08](https://github.com/uzimaru0000/tv/commit/a127b0881d26ec626fffee86fc3d29a59bfc247d))

<!-- generated by git-cliff -->
